@@ -19,7 +19,7 @@ class PersistQueueConsumer(AbstractConsumer):
         while True:
             t_start = time.time()
             item = pub.queue.get()
-            self.logger.debug(f'取出的任务时间是 {round(time.time() - t_start, 4)}    消息是：  {item}  ')
+            self.logger.debug(f'从本地持久化sqlite的 [{self._queue_name}] 队列中 取出的消息是：    消息是：  {item}  ')
             kw = {'body': json.loads(item), 'q': pub.queue, 'item': item}
             self._submit_task(kw)
 
